package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````X"5```````!``````````%BS````
M`````````$``.``+`$``&P`:``8````$````0`````````!``$```````$``
M0```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"0```````J`)````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````-@9````````V!D`````````
M$`````````$````%`````"``````````($`````````@0```````C3H`````
M``"-.@`````````0`````````0````0`````8`````````!@0````````&!`
M```````81@```````!A&`````````!`````````!````!@```&BM````````
M:+U```````!HO4```````*@$`````````!4`````````$`````````(````&
M````>*T```````!XO4```````'B]0```````,`(````````P`@````````@`
M````````!`````0```#$`@```````,0"0```````Q`)```````!$````````
M`$0`````````!`````````!0Y71D!````$"?````````0)]```````!`GT``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``!HK0```````&B]0```````:+U```````"8`@```````)@"`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`-X=*-.<]-D`$/&W$65$H\(C^75M!````!`````!````1TY5```````#
M`````@`````````1````20````0````(````(!`0``5`!(0H`@``@(8`@(()
M```)(`0(B*`01;H``@@`````20```$P```!/````4````%8```!7````6```
M`%H```!;`````````%T```!>````7P```&```````````````&[%WQ_.WD<M
M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/NA;&!K
M"4/69Z_,9D)%U>R)!W#3#13BGC)BV^W;S>.>#3J7"W^IG)OAIP(*H^#[20``
M``````````````````````````````````#Z`0``$@``````````````````
M```````.`0``$@````````````````````````"5````$@``````````````
M```````````#`0``$0````````````````````````"M`@``$@``````````
M``````````````#T`0``$@````````````````````````!%`P``$0``````
M``````````````````"5`0``$@````````````````````````!H`@``$@``
M``````````````````````"8`@``$@`````````````````````````D`0``
M$@`````````````````````````O````(``````````````````````````L
M`@``$@````````````````````````!-`P``$@``````````````````````
M```5`@``$@`````````````````````````Q`@``$@``````````````````
M``````"L`0``$@`````````````````````````Q`P``$@``````````````
M``````````!5`0``$@````````````````````````"V````$@``````````
M``````````````!%`0``$@````````````````````````!3`@``$@``````
M``````````````````"2`@``$@`````````````````````````W`0``$@``
M``````````````````````#O`@``$@````````````````````````!O`@``
M$@````````````````````````!#`P``$0````````````````````````#S
M`P``$@`````````````````````````3````(```````````````````````
M``"S`0``$@`````````````````````````3`0``$@``````````````````
M``````"$`@``$@`````````````````````````^````(```````````````
M``````````#&`@``$@````````````````````````!8````$@``````````
M``````````````"%`0``$@````````````````````````!U````$@``````
M``````````````````#R````$@````````````````````````"&````$@``
M```````````````````````.`@``$@````````````````````````"+`@``
M$@````````````````````````#6````$@````````````````````````#F
M`@``$@````````````````````````!W`0``$@``````````````````````
M```;`P``$@````````````````````````#\`@``$@``````````````````
M``````"[`@``$@````````````````````````!I`0``$@``````````````
M``````````#C`0``$@````````````````````````!V`@``$@``````````
M```````````````8`0``$@````````````````````````!"`@``$@``````
M```````````````````J`P``$@````````````````````````!]`@``$@``
M``````````````````````#?`@``$@````````````````````````"A````
M$@````````````````````````#.`@``$@````````````````````````"@
M`0``$@`````````````````````````:`@``$@``````````````````````
M```Y`@``$@`````````````````````````-`P``$@``````````````````
M``````#8`@``$0````````````````````````#E````$0``````````````
M```````````C`P``$@````````````````````````!$`P``(0``````````
M``````````````!@`@``$@````````````````````````!>`0``$@``````
M``````````````````!F````$@````````````````````````"F`@``$@``
M```````````````````````#`P``$@````````````````````````!:`@``
M$@````````````````````````#$````$@````````````````````````#\
M`P``$@`-`)!90```````7@````````!-!```$@`-`*!*0```````2`L`````
M```^`P``$@`-`.`C0```````^P$```````!M`P``$@`-`)!$0```````!0``
M``````";`P``$@`-`/!50```````G@,```````!S!```$@`-`*!$0```````
MX@$````````\!```$``8`!#"0`````````````````!^`P``$@`-`)!&0```
M````)0````````"Q`P``$@`-`'!)0```````3@`````````(!```$0`/``!@
M0```````!``````````D!```$@`-`$!#0```````,P````````!(!```$``8
M`&C20`````````````````!A!```$@`-`.!)0```````M@`````````7!```
M$``7`/#!0`````````````````#5`P``$@`-`,!&0```````W`````````!:
M!```$``7`!#"0`````````````````"`!```$0`7``C"0```````"```````
M``"+`P``$@`-`&!:0```````!0`````````=!```$@`-`.`E0```````+P``
M```````L!```$@`-`/!90```````90`````````9!```(``7`/#!0```````
M``````````#A`P``$@`-`,!)0```````'0````````"_`P``$@`-`-!#0```
M````OP````````"*!```$@`-`*!'0```````S@$`````````;&EB<&5R;"YS
M;RXU+C,P+C``7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S
M=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R
M;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R
M=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?
M<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O+C(`;&EB
M;2YS;RXV`&QI8G!T:')E860N<V\N,`!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E
M`'!T:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`')E860`;'-E96LV-`!L:6)C
M+G-O+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`
M=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R
M=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`
M7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T
M9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D
M9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI
M8F-R>7!T+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L
M:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L
M96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E
M9`!?7V1A=&%?<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`7U]B<W-?
M<W1A<G0`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P
M871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`$=,24)#
M7S(N,30`1TQ)0D-?,BXT`$=,24)#7S(N,RXR`$=,24)#7S(N,BXU`$=,24)#
M7S(N,RXT`"]U<W(O;&EB-C0O<&5R;#4O-2XS,"XR+W@X-E\V-"UT;&0M;&EN
M=7@M=&AR96%D+6UU;'1I+T-/4D4``````@`````````#``(`!`````0``P``
M````!``%``(`!``$``0`````````!``$`````P`$``0`!```````!``$````
M!````````````````@`$````!`````0`!``$`````@`$````!@`$``0`!```
M``0````"``0``P`$````!``$``0```````<`!``$`````0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``4`(@(`
M`!````!@````E)&6!@``!P"7!```$````!1I:0T```8`H@0``!````!R&6D)
M```%`*P$```0````=1II"0``!`"X!```$````'09:0D```,`Q`0````````!
M``$`TP$``!``````````=1II"0```@"X!````````*B_0```````!@````0`
M`````````````+"_0```````!@````<``````````````+B_0```````!@``
M``L``````````````,"_0```````!@````P``````````````,B_0```````
M!@```!(``````````````-"_0```````!@```!T``````````````-B_0```
M````!@```"$``````````````."_0```````!@```"0``````````````.B_
M0```````!@```"4``````````````/"_0```````!@```#X`````````````
M`/B_0```````!@```#\``````````````!C`0```````!P````$`````````
M`````"#`0```````!P````(``````````````"C`0```````!P````,`````
M`````````##`0```````!P````4``````````````#C`0```````!P````8`
M`````````````$#`0```````!P````@``````````````$C`0```````!P``
M``D``````````````%#`0```````!P````H``````````````%C`0```````
M!P````T``````````````&#`0```````!P````X``````````````&C`0```
M````!P````\``````````````'#`0```````!P```!```````````````'C`
M0```````!P```!$``````````````(#`0```````!P```!,`````````````
M`(C`0```````!P```!0``````````````)#`0```````!P```!4`````````
M`````)C`0```````!P```!8``````````````*#`0```````!P```!<`````
M`````````*C`0```````!P```!@``````````````+#`0```````!P```!D`
M`````````````+C`0```````!P```!H``````````````,#`0```````!P``
M`!P``````````````,C`0```````!P```!X``````````````-#`0```````
M!P```!\``````````````-C`0```````!P```"```````````````.#`0```
M````!P```"(``````````````.C`0```````!P```",``````````````/#`
M0```````!P```"8``````````````/C`0```````!P```"<`````````````
M``#!0```````!P```"@```````````````C!0```````!P```"D`````````
M`````!#!0```````!P```"H``````````````!C!0```````!P```"L`````
M`````````"#!0```````!P```"P``````````````"C!0```````!P```"T`
M`````````````##!0```````!P```"X``````````````#C!0```````!P``
M`"\``````````````$#!0```````!P```#```````````````$C!0```````
M!P```#$``````````````%#!0```````!P```#(``````````````%C!0```
M````!P```#,``````````````&#!0```````!P```#0``````````````&C!
M0```````!P```#4``````````````'#!0```````!P```#8`````````````
M`'C!0```````!P```#<``````````````(#!0```````!P```#@`````````
M`````(C!0```````!P```#D``````````````)#!0```````!P```#H`````
M`````````)C!0```````!P```#L``````````````*#!0```````!P```#P`
M`````````````*C!0```````!P```#T``````````````+#!0```````!P``
M`$```````````````+C!0```````!P```$(``````````````,#!0```````
M!P```$,``````````````,C!0```````!P```$0``````````````-#!0```
M````!P```$4``````````````-C!0```````!P```$8``````````````.#!
M0```````!P```$<``````````````.C!0```````!P```$@`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S__T%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D".B'____
M2(LUJ)L``$B+/=&;``!(B?+H438``$B+!=*;``"`.``/A"(!``!,BR5RFP``
M08L\).CQ^___08L\)("(.@0```+HX?O__X"(.@0```&+1"0<C7@%2&/_2,'G
M`^BW_O__3(M,)!"+5"0<QP74K0``!````$B)P4B)!<*M``!)BP%(B0%(C04V
M/0``2(E!"$C'P`C"0`!(BP!(B4$02(T%(#T``$B)01B#^@%^*T2-0OZ^`0``
M`$F#P`)F#Q]$``!)BP3QC7X$2(/&`4AC_TB)1/GX23GP=>B-0@1%,<"#P@-(
MBSUPK0``2)A(C36''@``2,=$P?@`````Z'G[__]!B<2%P'1X2(L]2ZT``$B-
M;"0LZ&']__\QP$B)[DB-/7D[``#H$!@``$B%P'1E2(L])*T``.C_^O__Z(K\
M__](@\0X1(G@74%<P^@Z_/__2(D%`ZT``$B)QTB%P'1LZ(;\__],BR4WF@``
M08L\).BV^O__QH#1"0```.FP_O__2(L]TZP``.AN^___08G$Z73___](BSVW
MK```2(7_=`?HY3,``.N(2(T]I3H``$B)[NB$%P``2(D%E:P``$B)QTB%P`^$
M9O___^O5OP$```#HU?K__P\?1```\P\>^C'M28G17DB)XDB#Y/!05$G'P&!:
M0`!(Q\'P64``2,?'X"-``/\5NID``/20\P\>^L-F+@\?A```````D$B-/>F;
M``!(C07BFP``2#GX=!5(BP66F0``2(7`=`G_X`\?@`````###Q^``````$B-
M/;F;``!(C36RFP``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!5V9``!(A<!T
M"/_@9@\?1```PP\?@`````"`/8F;````=1=52(GEZ'[____&!7>;```!7<,/
M'T0``,-F9BX/'X0```````\?0`#KCF8N#Q^$```````/'T``05=,C4\X059!
M54%455-(@>P0`@``2(U4)(A,C50D"$F)T&8/'T0``$&+`4F+,4F#P!!)@\$(
M#\B)P$B)\4F)0/!(B?!(P>D@2,'H*$C![C@E`/\``$@)\$B)SDC!X0A(P>88
M@>$``/\`B?9("?!("<A)B4#X33G0=:Y(C;(``@``#Q^``````$B+0FA(,T)`
M2(/""$@S0@A(,T+X2(T,`$C!Z!]("<B#X/](B4)X2#GR==5,BP=,BT\02(M?
M($R+5QA,B<!,B<)(BW0DD$R+="2@2,'J&TC!X`5("=`#1"2(28VL,IEY@EJ-
ME!B9>8):3(G(3(G#3#'02"-'"$C!XQY,,=!$C20"2(M7"$B+1PA,B>9(P>(>
M2,'H`D@)T$R)RDC![AN)P4@QRDPAPDPQRD@!ZDR)Y4C!Y05("?5(`=5,B<)(
MP>H"08GM2`G32(M4))A(,=A!B=M,(>!)C901F7F"6D@QR$J-C#&9>8):2(TT
M$$B)ZDC![1M(N.#___\?````2,'B!8/E'T@APD@)ZD@!\DR)YDG![`)(P>8>
MB=5,">9(,?-!B?1,(>M,,=M(`<M(B=%(P>H;2,'A!8/B'T@AP4@)RDR)Z4G!
M[0)(P>$>2`':3`GI3(ML)*B)TT@QSD&)SD@A[D^-G"N9>8):3#'F3`'>28G3
M2,'J&TG!XP6#XA])(<-)"=-(BU0DL$D!\TB)[DC![0)(P>8>28V4%)EY@EI%
MB=U(">Y(,?&)]4@AV4PQ\4@!RDR)V4C!X05((<%)P>L;08/C'TP)V4R+7"2X
M2`'12(G:2,'K`DC!XAY/C9P>F7F"6D&)S$@)VD@QUHG33"'N2#'N20'S2(G.
M2,'I&TC!Y@6#X1]((<9("<Y(BTPDP$P!WDV)ZTG![0))P>,>2(V,#9EY@EI!
MB?9-">M,,=I%B=U,(>)(,=I(`=%(B?)(P>X;2,'B!8/F'T@APD@)\DB+="3(
M2`'*3(GA2,'A'DG![`)(C;0SF7F"6HG53`GA23'+08G,32'S33'K3`'>28G3
M2,'J&TG!XP6#XA])(<-)"=-(BU0DT$D!\TR)]DG![@)(P>8>28V4%9EY@EI$
MB=M,"?9(,?%!B?9((>E,,>%(`<I,B=E)P>L;2,'A!4&#XQ]((<%,"=E,BUPD
MV$@!T4B)ZDC![0)(P>(>3XV<')EY@EI!B<U(">I(,=:)U4@AWDPQ]DD!\TB)
MSDC!Y@5(P>D;2"'&@^$?2`G.2(M,).!,`=Y)B=M(P>L"2<'C'DF-C`Z9>8):
M08GT20G;3#':1(G;3"'J2#'J2`'12(GR2,'N&TC!X@6#YA]((<)("?)(BW0D
MZ$@!RDR)Z4G![0)(P>$>2(VT-9EY@EI!B=9,">E),<M!B<U-(>-),=M,`=Y)
MB=-(P>H;2<'C!8/B'TDAPTD)TTB+5"3P20'S3(GF2,'F'DG![`)(C903F7F"
M6D2)W4P)YD@Q\4&)]$PA\4PQZ4@!RDR)V4G!ZQM(P>$%08/C'T@AP4P)V4R+
M7"3X2`'13(GR2<'N`DC!XAY/C9P=F7F"6HG+3`GR2#'608G62"'N3#'F20'S
M2(G.2,'I&TC!Y@6#X1]((<9("<Y(BPPD3`'>28GK2,'M`DG!XQY)C8P,F7F"
M6D&)]4D)ZTPQVD2)W4@AVDPQ\D@!T4B)\DC![AM(P>(%@^8?2"'"2`GR2(MT
M)`A(`<I(B=E(P>L"2,'A'DF-M#:9>8):08G42`G923'+B<M-(>M),>M,`=Y)
MB=-(P>H;2<'C!8/B'TDAPTD)TTB+5"0020'S3(GN2<'M`DC!YAY(C905F7F"
M6D6)WDP)[D@Q\4&)]4PAX4@QV4@!RDR)V4G!ZQM(P>$%08/C'T@AP4P)V4@!
MT4R)XDG![`)(P>(>B<U,">),BV0D&$@QUD&)TTPA]DJ-G".9>8):3#'N2`'>
M2(G+2,'I&TC!XP6#X1]((<-("=E,B?-)P>X"2,'C'HG)3`GS2`'.2(M,)"!(
M,=I!B?1((>I)C8P-F7F"6DV)Y4PQVDG![1M(`<I,B>%(P>$%3`GIB<E(`<I(
MB>E(P>T"2,'A'D&)U4@)Z4B)W8G;2#'-,>Y(BVPD*$V-G"NAZ]EN3(GM20'S
M3(GN2,'F!4C![1M(`UPD,$@)[HGV3`'>38GC2<'L`DG!XQZ)]4T)XTF)S(G)
M2`-,)#A-,=Q$,>),C:03H>O9;DB)ZDB)ZTC!ZQM(P>(%2`G:B=))C1P43(GJ
M2<'M`DC!XAY!B=Q,">I-B=U%B=M,`UPD0$DQU40Q[DV)Y4B-M#&AZ]EN3(GA
M2<'M&TC!X05,">F)R4@!\4B)[DC![0)(P>8>08G-2`GN2(G5B=)(,?4QZTR)
M[4F-G!NAZ]EN38GK2,'M&TG!XP5)">M%B=M)`=M,B>-(P>,>2<'L`D2)W4@#
M5"1(3`GC28GTB?9(`W0D4$DQW$0QX4F)[$B-C`JAZ]EN2(GJ2<'L&TC!X@5,
M">*)TD@!RDR)Z4G![0)(P>$>08G43`GI28G=B=M(`UPD6$DQS44QZTV)Y4Z-
MG!ZAZ]EN3(GF2<'M&TC!Y@5,">Z)]DP!WDF)ZTC![0))P>,>08GU20GK2(G-
MB<E,,=TQZDB-K!.AZ]EN3(GJ3(GK2,'K&TC!X@5("=J)TDB-7!4`3(GB2<'L
M`DC!XAZ)W4P)XDV)W$@#3"1@18G;23'43`-<)&A$,>9)B>Q(C;0QH>O9;DB)
MZ4G![!M(P>$%3`GAB<E(`?%,B>Y)P>T"2,'F'D&)S$P)[DF)U8G22`-4)'!)
M,?5$,>M-B>5)C9P;H>O9;DV)XTG![1M)P>,%30GK18G;20';2(GK2,'M`DC!
MXQY%B=U(">M(B?6)]D@#="1X2#'=,>E,B>U(C8P*H>O9;DR)ZDC![1M(P>(%
M2`GJB=)(`<I,B>%)P>P"2,'A'HG53`GA28G<B=M),<Q%,>-)B>Q(`YPD@```
M`$Z-G!ZAZ]EN2(GN2<'L&TC!Y@5,">:)]DP!WDV)ZTG![0))P>,>08GT30GK
M28G-B<E(`XPDB````$TQW40QZDR-K!.AZ]EN3(GB3(GC2,'K&TC!X@5("=J)
MTDF-7!4`2(GJ2,'M`DC!XAY!B=U(">I,B=U%B=M,`YPDD````$@QU3'N3(GM
M2(VT,:'KV6Y,B>E(P>T;2,'A!4@)Z8G)2`'Q3(GF2<'L`DC!YAZ)S4P)YDF)
MU(G223'T1#'C28GL28V<&Z'KV6Y)B>M)P>P;2<'C!4T)XT@#E"28````18G;
M20';3(GK2<'M`DC!XQY%B=Q,">M)B?6)]D@#M"2@````23'=1#'I38GE2(V,
M"J'KV6Y,B>))P>T;2,'B!4P)ZHG22`'*2(GI2,'M`DC!X1Y!B=5(">E(B=V)
MVT@#G"2H````2#'-03'K3(GM3HV<'J'KV6Y,B>Y(P>T;2,'F!4@)[HGV3`'>
M38GC2<'L`DG!XQZ)]4T)XTF)S(G)33'<1#'B3(VD$Z'KV6Y(B>I(B>M(P>L;
M2,'B!4@)VHG228T<%$R)ZDC!XAY)P>T"08G<2`.,)+````!,">I-B=U%B=M,
M`YPDN````$DQU40Q[DV)Y4B-M#&AZ]EN3(GA2<'M&TC!X05,">F)R4@!\4B)
M[DC![0)(P>8>08G/2`GN2(G538G]B=)(,?5)P>4%2`.4),`````QZTF-G!NA
MZ]EN38G[2<'K&TT)ZTZ-+!M,B>-)P>P"28GS2,'C'D2)[8GV3`GC23';08G>
M1#'938GK2<'M&TG!XP5(C90*H>O9;D&#Y1],B?E(P>$>22'#2<'O`DT)ZTF)
MW4D!TTP)^;K<O!N/08G/20G-18G<3"'[22'M20G=2(N<),@```!(`=-(`=Y)
M`?5,B=Y)P>L;2,'F!4&#XQ]((<9,"=Y,`>Y)B>U(P>T"2<'E'HGS20GM3`GI
M38GK1(GM32'[3"'A3`G93(N<)-````!)`=--`?--B>9)P>P"20'+2(GQ2,'N
M&TC!X06#YA])P>8>2"'!2`GQ3(GN3`'930GF18GT3`GV08G+2"'>32'E20GU
M2(NT)-@```!(`=9,`?Y)B=](P>L"20'U2(G.2<'G'DC!Y@5(P>D;20G?2"'&
M@^$?30G^1(G[2`G.3(GY32'>3"'A3`'N20G.2(N,).````!!B?5(`=%(`>E)
M`<Y(B?%(P>X;2,'A!8/F'T@AP4@)\4R)_DP!\4V)WDG!ZP))P>8>B<U-"=Y%
MB?-,"?9,(>Y-(=])"?=(B[0DZ````$@!UDP!YDD!]TB)SDC!Z1M(P>8%@^$?
M2"'&2`G.3`'^38GO2<'M`DG!YQY!B?1-">]-"?Y,B?E%B?U,(=E)(>Y)"<Y(
MBXPD\````$@!T4@!V4D!SDB)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'Q28GN
M2,'M`DG!YAZ)RTD)[D2)]4P)]DPAYDDA[TD)]TB+M"3X````2`'63`'>20'W
M2(G.2,'I&TC!Y@6#X1]((<9("<Y,`?Y-B>=)P>P"2<'G'D&)\TT)YTT)_DR)
M^46)_$@AZ4DAWDD)SDB+C"0``0``2`'13`'I28G=2,'K`DD!SDB)\4C![AM(
MP>$%@^8?2<'E'D@AP4@)\4R)_DP!\4D)W42)ZTP)[D&)SDPAWDDAWTD)]TB+
MM"0(`0``2`'62`'N20'W2(G.2,'I&TC!Y@6#X1]((<9("<Y,`?Y-B=])P>L"
M2<'G'HGU30G?30G]3(GY18G[2"'932'U20G-2(N,)!`!``!(`=%,`>%)`<U(
MB?%(P>X;2,'A!8/F'T@AP4@)\4R)_DP!Z4V)]4G![@))P>4>08G,30GU18GN
M3`GN2"'N32'W20GW2(NT)!@!``!(`=9(`=Y)`?=(B<Y(P>D;2,'F!8/A'T@A
MQD@)SDP!_DF)[TC![0))P><>B?-)">]-"?U,B?E$B?U,(?%-(>5)"<U(BXPD
M(`$``$@!T4P!V4D!S4B)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'I38GE2<'L
M`DG!Y1Y!B<M-">5%B>Q,">Y((=Y-(>=)"?=(B[0D*`$``$@!UDP!]DD!]TB)
MSDC!Z1M(P>8%@^$?2"'&2`G.3`'^28G?2,'K`DG!YQY!B?9)"=]-"?U,B?E$
MB?M,(>%-(=U)"<U(BXPD,`$``$@!T4@!Z4R)W4G!ZP))`<U(B?%(P>X;2,'A
M!8/F'TC!Y1Y((<%("?%,B?Y,`>E,"=U!B>M(">Y!B<U,(?9-(=])"?=(B[0D
M.`$``$@!UDP!YDD!]TB)SDC!Z1M(P>8%@^$?2"'&2`G.3`'^38GW2<'N`DG!
MYQY!B?1-"?=,"?U,B?E%B?Y,(=E,(>U("<U(BXPD0`$``$@!T4@!V4R)ZTG!
M[0)(`<U(B?%(P>X;2,'A!8/F'TC!XQY((<%("?%,B?Y(`>E,">M!B=U("=Z)
MS4PAYDTA[TD)]TB+M"1(`0``2`'63`'>38GC2<'L`DD!]TB)SDG!XQY(P>8%
M2,'I&TT)XT@AQH/A'TP)VT6)W$@)SDR)V4@AZTPAZ4P!_D@)RTB+C"10`0``
M08GW2`'13`'Q38G>2`'+2(GQ2,'N&TC!X06#YA]((<%("?%(`=E(B>M(P>T"
M2,'C'HG.2`G=B>M)">Y-(?Y)(=M-"?-,B[0D6`$``$D!UD@#E"1@`0``30'U
M3`'B30'=28G+2,'I&TG!XP6#X1])(<-,"=F)R4P!Z4V)_4G![P))P>4>08G+
M30GO38G<3`G]38G^2<'L&T6)_4DAWD@A]4P)]4R+M"1H`0``2`'53(G:2,'B
M!4P)XHG22`'52(GR2,'N`DC!XAY!B>Q("=:ZUL%BRDDQ]T0Q^4D!UDP!\TV)
MYD@!RTR)X4G![AM(P>$%3`GQB<E(`<M,B=E)P>L"2,'A'D&)WDD)RTB)\8GV
M3#'9,<U(BXPD<`$``$@!T4P!Z4V)]4@!S4R)\4G![1M(P>$%3`GIB<E(`<U,
MB>%)P>P"2,'A'D&)[4D)S$B+C"1X`0``2`'12`'Q3(G>18G;3#'F,=Y,B>M(
M`<Y,B>E(P>L;2,'A!4@)V8G)2`'.3(GQ2,'A'DG![@*)\TD)SDB+C"2``0``
M2`'13`'938GC18GD33'S1#'=28G;2`'-2(G92<'K&TC!X05,"=E,BYPDB`$`
M`(G)2`'-3(GI20'32<'M`DC!X1Y-`>--B?1!B>],">E%B?9),<Q$,>9-B?Q)
M`?-,B?Y)P>P;2,'F!4P)YD&)]$B)WDC!ZP)(P>8>30'<28G+B<E("?-(B[0D
MD`$``$6)Y4DQVT@!UD0QW4V)ZTP!]D@!]4R)[DC!Y@5)P>L;3`G>38G[2<'O
M`HGV2<'C'D@!]4B+M"28`0``30G[08GN2`'62`'Q2(G>B=M,,=Y!,?1,B?9)
M`<Q,B?%(P>X;2,'A!4@)\8G)20',3(GI2<'M`DC!X1Y%B>=)"<U(BXPDH`$`
M`$R)_DC![AM(`=%(`=E,B=M%B=M,,>LQZT@!RTR)^4C!X05("?%,B?9)P>X"
MB<E(P>8>2`'+2(N,)*@!``!,"?:)W4@!T4P!V4V)ZT6)[4DQ\T4QW$F)ZTD!
MS$B)Z4G!ZQM(P>$%3`G928GSB?:)R4D!S$R)^4G![P)(P>$>18GF20G/2(N,
M)+`!``!-,?M(`=%$,=M-B?-,`>E)P>L;2`'+3(GQ2,'A!4P)V4R+G"2X`0``
MB<E(`<M(B>E(P>T"20'32,'A'D&)W4P!WD@)Z4R)_4V)ZT6)_T@QS4G!ZQM$
M,>5(`?5,B>Y(P>8%3`G>28G+B<F)]D@!]4R)]DC!YAY)P>X"08GL20GV2(NT
M),`!``!-,?-(`=9$,=M-B>-,`?Y)P>L;2`'S3(GF2,'F!4P)WDV)ZTG![0*)
M]DG!XQY(`?-(B[0DR`$``$T)ZT&)WT@!UD@!\4R)]D6)]DPQWC'U3(G^2`'-
M3(GY2,'N&TC!X05("?%,B=Y%B=N)R4@!S4R)X4G![`)(P>$>08GM20G,2(N,
M)-`!``!,,>9(`=$Q\TR)[DP!\4@!RTR)Z4C!X05(P>X;2`GQ3(G^2<'O`HG)
M2,'F'D@!RTB+C"38`0``3`G^08G>2`'13`'938GC18GD23'S03'K3(GU20'+
M3(GQ2,'M&TC!X05(">F)R4D!RTR)Z4G![0)(P>$>1(G=20G-2(N,).`!``!(
M`=%,`>%)B?2)]DTQ[$0QXTF)[$@!RTB)Z4G![!M(P>$%3`GAB<E(`<M,B?%)
MP>X"2,'A'D&)W$P)\4R+M"3H`0``20'63`'V38GN18GM23'.13'S38GF3`'>
M38GC2<'N&TG!XP5-"?-)B>Y(P>T"2<'F'D6)VTP)]4R+M"3P`0``3`'>08GS
M20'630'U28G.B<E),>Y$,?--B=Y,`>M-B=U)P>X;2<'E!4T)]4V)YDG![`))
MP>8>18GM30GT3(NT)/@!``!,`>M!B=U)`=9,`?%)B>Z)[4TQYD0Q]DV)[D@!
MSDR)Z4G![AM(P>$%3`GQ2`'Q3(G>2,'F'DG!ZP)(`Y0D``(``$D)\TR)YDP!
MPD0#9R!,,=Y(`>I%`=I,B6<@,?-(B<Y,B5<82,'F!4@!VD@A\$B)S@-/"$C!
M[AM(B4\(@^8?2`GP`=!(B0=,B>A)P>T"2,'@'DD)Q44!Z4R)3Q!(@<00`@``
M6UU!7$%=05Y!7\-F#Q^$``````!!5T%6055!5%532(/L"$B%_P^$L0```$B+
M!5*"``!,BS!-A?8/A)X````/M@=)B?](B?6$P'0$/#UU544Q[4V+)DV%Y'0P
M36/M3(GS#Q]``$R)ZDR)_DR)Y^A"X___A<!U!T.`/"P]=$=,BV,(2(/#"$V%
MY'7:2(/$"$R)X%M=05Q!74%>05_##Q^$``````!)B?U!#[9%`4F#Q0&$P'0$
M/#UU[T4I_>N5#Q^``````$PI\T^-9"P!2,'[`XE=`.NU#Q^``````$4QY.NI
M#Q\`55-(B?M(@^P82(UL)`QFD#'`2(GN2(G?Z!/___](A<!T/DB+!7>!``!(
M8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U
M\.NV9@\?1```2(/$&%M=PV8/'X0``````$%7,<!!5D%505152(GU4TB)^TB#
M["B`/CT/E,!(`<5(B>_H">/__TB-="0<2(G?28G$,<#HA_[__TB%P`^$_@``
M`$B)QTF)Q>CCXO__3#G@#X/*````2&-,)!Q,BS7.@```2,'A`P^V`X3`#X2/
M`0``/#T/A(<!``!(B=@/'T``#[90`4B#P`&$TG0%@/H]=>](*=A(F$D##DJ-
M?"`"28G-Z,KA__])B44`2(7`#X1A`0``28L&2&-4)!Q(C4L!2(L4T`^V`X@"
M/#UT(83`=0SK&V8/'T0``#P]=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`9@\?
M1```#[9,!0"(3`(!2(/``83)=>\QP$B#Q"A;74%<05U!7D%?PV8/'T0``#'`
M9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ\T/'T``3(LUZ7\``$V+/DF#/P`/
MA+,```!,B?A%,>UF#Q]$``!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+
M!3^2``"%P'5;QP4QD@```0```$B)]^C9X/__2(G'2(7`='5-8\5,B?Y*C0S%
M`````$R)1"0(2(G*2(D,).@2XO__3(M$)`A(BPPD28D&2(G'2L=$QP@`````
M1(EL)!SIAO[__TR)_^@(X___28D&2(G'2(7`="%-8\5*C0S%`````.O-,<#I
MC_[__[X0````13'MZ6?___^#R/_I[_[__P\?0`!(A?\/A"<!``!!5D%50515
M2(G]4TB![)````"`/P!U$$B!Q)````!;74%<05U!7L/HZ^#__TF)Q$B%P'3C
M2(GC3(GGZ,CB__](A<`/A*,```!F@W@3+DR-<!-TY&:!>!,N+@^$L````$B)
M[^B@X/__3(GW28G%Z)7@__]!C7P%`DAC_^C(W___38GQ28GHO@$```!)B<5(
MB<<QP$C'PO____](C0V^'@``Z`+B__^_`0```$B)VDR)[NBRX?__3(GO@_C_
M=!"+1"08)0#P```]`$```'1BZ+7?__],B>_H'>#__TR)Y^@EXO__2(7`#X5=
M____3(GGZ*3A__](B>_HG-___TB!Q)````!;74%<05U!7L,/'T``08!^`@`/
MA!W____I0/___P\?A```````PP\?@`````#HP_[__^N<D%5(B?Y(B?V_`0``
M`$B![)````!(B>+H=>#__X7`=4&+5"08@>(`\```@?H`0```=`B!^@"@``!U
M*4B)[[X"````Z#KA__^%P`^4P$B!Q)`````/ML!=PV8/'X0``````#'`2('$
MD````%W##Q]$``!!5[K_#P``059!54%428GT54B)_4B-/:(=``!(@>P0$```
M9$B+!"4H````2(F$)`@0```QP$F)Y4R)[NB@W___A<!^?(U0_TB+#0I]``!,
M8_)"@#PT`$2+.75=A=)T:TR)\KXO````3(GOZ-'=__](A<!T5D2)_^ADW?__
M3(GQ3(GJ2(GN2(G'Z$/?__](BX0D"!```&1(,P0E*````'5"2('$$!```%U!
M7$%=05Y!7\,/'X``````3&/PZZ(/'P!(BP61?```1(LX1(G_Z`[=__],B>)(
MB>Y(B<?H(-[__^NKZ(G?__]F#Q^$``````!(@^P(2(L%77P``(LXZ-[<__](
MBQ6'?```2(/$"$B-#:Q;``!(B<=(C36N'```Z0W@__]F9BX/'X0``````&:0
M4TB+'2!\``"+.^BAW/__2(G'Z*G___^+.^B2W/__3(T%`1X``$4QR5M(Q\+P
M54``2(G'3(G!2(TU>QP``.D>WO__9F8N#Q^$```````/'P!!5%532('L("``
M`&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```.ARW?__3(T-$QP``+H!
M$```2(GO08G`2(T--AP``+X!````,<#H+=___[H`$```3(GF2(GOZ/W=__]%
M,<"%P'@NC7@!2(G#2&/_Z*C<__])B<!(A<!T&$ACVTR)YDB)QTB)VN@_W___
MQ@08`$F)P$B+A"08(```9$@S!"4H````=0](@<0@(```3(G`6UU!7,/H,=[_
M_Y#I.____V9F+@\?A```````05=)B?=!5D%5051)B?Q(C3VD&P``55-(@>RH
M$```9$B+!"4H````2(F$))@0```QP$F)Y4R)[NAD^/__OB\```!,B>=(B<7H
M=-W__TB%P'0_3(GF2(T]9QL``#'`Z'[Y__],B>!(BXPDF!```&1(,PPE*```
M``^%80$``$B!Q*@0``!;74%<05U!7D%?PV:03(GGZ'C<__](C34P&P``3(G_
M08G&Z);=__](B<,/'P!(A=MTG(`[``^$P@```$B%[7032(G>2(GOZ&+=__^%
MP`^$E````$B)W^@RW/__B<)(F(!\`_\O=1@/'X``````@^H!2&/"@'P#_R_&
M!`,`=.]!C406`3W_#P``#X]`____28G8N@`0``"^`0```#'`3(V\))````!(
M@^P(2(T-A!L``$%43(T-E1H``$R)_^ALW?__3(GJ3(G^OP$```#H'-W__UI9
MA<!U$(M$)!@E`/```#T`@```=$9(C35>&@``,?_HR-S__TB)P^DP____2(7M
M=`:`?0`N=!5(C1W3&0``N@$```#I9?___P\?0`"`?0$`=,3KXP\?A```````
MO@$```!,B?_H`]W__X7`=:E,B?Y(C3WW&0``Z!#X__],B?_H*-S__^F(_O__
MZ#[<__]F9BX/'X0```````\?``^V!TF)^(3`=!=F#Q]$``!(@\<!/"\/M@=,
M#T3'A,!U[TR)P,-F9BX/'X0``````$B%_P^$QP```%6`/P!(B?T/A*(```#H
MU=K__TB-5`7_2#G5<A3IFP```&8/'T0``$B#Z@%(.=5T)8`Z+W3R2#G5#X-^
M````2(/J`4@YU70.@#HO="!(@^H!2#G5=?*`.B]T54B-/4<9``!=Z7#;__^`
M.B]U"4B#Z@%(.=5R\D@IZC'`2(U*`DB!^0`0``!W'TB#P@&Y`!```$B)[DB-
M/=UZ``#H^-C__TB-!=%Z``!=PP\?@`````!(C3V&&```7>D;V___2#G5=:OK
MD@\?0`!(C3UN&```Z03;__\/'T``53'22(T]R1@``$B#[$!F#V\%:E<``&1(
MBP0E*````$B)1"0X,<!FB50D,$B-;"0,#RE$)!!F#V\%4U<```\I1"0@Z"GV
M__\QP$B-/8P8``#H&_;__S'`2(T]AA@``.@-]O__,<!(C3V!&```Z/_U__\Q
MP$B-/7H8``#H\?7__S'`2(T]?!@``.CC]?__,<!(C3TC&```Z-7U__\QP$B-
M/6P8``#HQ_7__S'`2(T]:!@``.BY]?__,<!(C3UD&```Z*OU__\QP$B-/?07
M``#HG?7__S'`2(GN2(T]3Q@``.B\]/__2(7`=!%(B<9(C3TG&```,<#HYO7_
M_TB)[DB-/3L8```QP.B5]/__2(G&2(7`=`Y(C3TW&```,<#HO_7__TB)[DB-
M/3$8```QP.AN]/__2(G&2(7`=#Y(C3UX%P``,<#HF/7__S'`2(TU-Q@``$B-
M/9P7``#H@_7__TB+1"0X9$@S!"4H````=5Q(@\1`7<,/'T0``$B)[DB-/>H7
M```QP.@7]/__2(G&2(7`=!=(C3UX%P``,<#H0?7__^NG#Q^``````$BX4$%2
M7T-,14%(.40D(76/9H%\)"E./76&2(UT)"OKR.A2V?__9I"+!8IX``"#^/]T
M!<,/'T``2(/L&$B-/247```QP$B-="0,Z*GS__](B<(QP$B%TG02#[82@/HP
M#Y7!,<"$T@^5P"'(B05'>```2(/$&,-FD$B#[`CH)]G__XG'Z+#7__](A<!T
M`TB+`$B#Q`C##Q\`050QP%5(B?U(C3VW%P``4TB#[!!(C70D#.A"\___2(GN
M2(7`=`B`.`!(B<-U&DB-/9$7```QP.AD]/__2(/$$%M=05S##Q\`2(G'Z.#7
M__](A<!UYTB)[^ASU___2(G?28G$Z&C7__])C7P$`NB>UO__2(/L"$F)Z+X!
M````4TC'PO____](B<=)B<1,C0W\%0``2(T-W18``#'`Z,_8__],B>9(C3T;
M%P``,<#H[O/__UA:ZX9F+@\?A```````05=!5D%505154TB)^TB-/:45``!(
M@>P(@@``9$B+!"4H````2(F$)/B!```QP$B-!6$6``!,C:PDD````$C'1"0P
M`````$B)1"0@2(T%$Q4``$R)[DB)1"0H2(T%Z14``$B)1"1H2(T%+A8``$B)
M1"1P2(T%[A4``$B)1"1X2(T%'A8``$B)A"2`````2(T%$Q8``$B)1"1(,<!(
MQX0DB`````````!(QT0D4`````#HZ_'__TB%P'0,@#@`2(G%#X7Z!```,<#H
M4_[__TB)Q4B%P`^$/P0``$B)[^@OUO__2(U\``'H9=7__T0/MD4`28G$183`
M=#M-B>=,C36N%0``9@\?1```3(G_3(GQ2,?"_____S'`O@$```!(@\4!28/'
M`NB'U___1`^V10!%A,!UU4R-="1@2(T]$A4``.L8#Q^``````$F+?@A)@\8(
M2(7_#X27`0``3(GN,<#H/?'__TB)Q4B%P'3=@#@`=-A(B<?HR/7__X7`=,Q(
MB>_H?-;__TF)P$B%P`^$8`$``$R)P8L12(/!!(V"__[^_O?2(=`E@("`@'3I
MB<+!ZA"I@(````]$PDB-40)(#T3*B<(`PDR)XDB#V0-,*<&+,DB#P@2-AO_^
M_O[WUB'P)8"`@(!TZ8G&3(D$),'N$*F`@```#T3&2(UR`D@/1-:)QD``QDB#
MV@-,*>)$C;P1!`0``$UC_TR)_^@TU/__051,C0VL$P``2(T-B10``$B)Q4B-
M!8@4``!(Q\+_____O@$```!03(M$)!!(B>\QP.A>UO__OL`!``!(B>_HP=;_
M_T%805F#^/]U$NB#U?__1(L(08/Y$0^%$P,``$R)ZDB)[K\!````Z$;5__]!
MB<:%P`^$NP```$B+!;1R``!(BPM)B>A%,>1(C17$%```O@$```!(BS@QP.A%
MT___2(N$)/B!``!D2#,$)2@````/A7$(``!(@<0(@@``3(G@6UU!7$%=05Y!
M7\-F#Q^$``````!(BVPD($4Q]NL39@\?1```26/&2(MLQ"!(A>UT.X!]``!T
M-4B)[T&#Q@'H(?3__X7`=-U(B>_HU=3__TF)P$B%P`^%6?[__TECQDB+;,0@
M2(7M=<D/'T``13'`Z4#^__^+A"2H````)0#P```]`$````^%+O___T2+I"2L
M````Z-S4__]!.<0/A1C___^+A"2H````)?\!```]P`$```^%`?___TR)_^BT
MTO__2(T](!,``$R)[DF)Q#'`Z/#N__](B<=(A<`/A"0"``#H/]3__TB+.TB)
MQN@T]O__28G%2(7`#X0(`@``3(GOZ##3__^#^`-^.TACT+D%````2(T]U!(`
M`$F-=!7\\Z8/E\*`V@"$TG4;@_@$#X3B!0``@^@$2)A!@'P%_R\/A-$%``"0
M,<#HJ?K__X7`=14Q]DR)[^@KT___08G'A<`/A:@!``!(C35!$@``2(T]PA$`
M`#'`Z(OO__](C1VJ$@``3(TM;A$``.AHTO__4TC'PO____])B>A03(T-5A$`
M`+X!````3(GG2(T-5Q(``#'`Z!_4__]86NM%#Q\`Z%/3__^#.!%U2N@ITO__
M08/&`4B#[`A-B>E328GH2(T-,A(``+X!````059(Q\+_____3(GG4#'`Z-K3
M__](@\0@OL`!``!,B>?H.=3__X/X_W2L2(GOZ`S2__],B>9(C3V[$```,<#H
MV^[__TR)Y^@S^O__Z:G]__]F#Q]$``!(C3UK$0``13'DZQ$/'T``26/$2(M\
MQ$!(A?]T.4R)[C'`08/$`>A=[?__2(7`=."`.`!TVTB)Q^BKTO__2(G%2(7`
M#X5X^___26/$2(M\Q$!(A?]UQ[\-````2(TM%1$``.C1T/__0;A3````28G$
MZ6O[__](BP6\;P``2(L+28GH13'D2(T5C!$``+X!````2(LX,<#H3=#__^D#
M_?__#Q^$``````!(B<?H>/G__TB)[^@PTO__28G$Z>/\__\/'X0``````$R+
M*^GP_?__N@(```!(Q\;N____B<?HE=+__TB-A"3P`0``N@8```!$B?](B<9(
MB00DZ!G0__^`O"3P`0```'4.@+PD\0$``$,/A),$```QTC'V3(VT)'`!``!$
MB?_H3=+__[B)J\WO2,>$)'`!```!(T5G2(F$)'@!``!(+8O.$E=(B80D@`$`
M`$@%\@08*TB)A"20`0``2(V$)*@!``!(QX0DB`$``'94,A!(QX0DF`$`````
M``!(QX0DH`$```````#'A"3H`0```````$B)1"08#Q]``$B+-"2Z`(```$2)
M_^AGS___2(G!08G`A<`/CF4!``!(B[PDF`$``$B+E"2@`0``2&/!2(L<)(TT
MST@Y_DB)M"28`0``2(/2`$C!Z!U(`=!(8Y0DZ`$``$B)A"2@`0``A=(/A;$`
M``!!@_@_#XX)`P``08U`P(E$)!3!Z`9!B<6)1"0(28/%`4G!Y09)`=UF+@\?
MA```````\P]O"_,/;U,03(GW2(/#0/,/;UO@\P]O8_`/$8PDJ`$```\1E"2X
M`0``#Q&<),@!```/$:0DV`$``.BAU/__3#GK=;R+1"0(1(M$)!3!X`9!*<!(
MBWPD&$ECT+E(````3(GN1(E$)`CH`\___T2+1"0(1(F$).@!``#IZ?[__Y!!
MN$````!(BT0D&$B+-"1(B4PD"$$IT$0YP4B-/!!$#T[!26/82(G:Z`/1__^+
MA"3H`0``2(M,)`@!V(/X0(F$).@!```/A9W^__]!B<A,B?=!*=A(`QPD1(E$
M)`CH_M/__T2+1"0(Z>/^__]$B?_HC,W__TB+A"28`0``BYPDF`$``$2+K"2@
M`0``2,'H`P_+@^`_00_-C4@!2)C&A`2H`0``@(/Y.`^.O0$``+I`````2&/Q
M2`-T)!@IRG0/,<")P8/``<8$#@`YT'+S3(GWZ(O3__]F#^_`2,>$)-@!````
M````#Q&$)*@!```/$80DN`$```\1A"3(`0``3(GW1(FL).`!``!,C;PD(0$`
M`$R-M"1H`0``B9PDY`$``$R-+;H-``#H-=/__TB+A"1P`0``#[>4)'`!``!)
MB<!(P>@0B(0D(0$``&;!P@A)P>@8BX0D>`$``&:)E"0B`0``#\B)A"0D`0``
MBX0D@`$```_(B80D*`$``(N$)(@!```/R(F$)"P!``"+A"20`0``#\B)A"0P
M`0``2(V$)$`!``!(B00D2(G#ZPYF#Q]$``!%#[8'28/'`4B)WT4/ML!,B>F^
M`0```$C'PO____\QP$B#PP+H!\___TDYWG722(T%40T``,:$)&@!````4/]T
M)`A(C0T)#0``28GH3(GG,<"^`0```$R-#?0+``!(Q\+_____Z,?.__]97NG\
M^O__2(M;"$B%VP^$(_K__TB)W^@+S?__2(/X`P^&$?K__TB-=`/\N04```!(
MC3VM#```\Z8/E\`<`(3`3`]$Z^GN^?__28G=Z6G]__^Z.````$ACP3'_2`-$
M)!@IRH/Z"',P]L($#X77````A=(/A&S^___&``#VP@(/A&#^__\Q_V:)?!#^
MZ53^__\/'X``````B=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!T(/@
M^(/X"`^"(O[__X/@^#'2B=:#P@A(B3PQ.<)R\^D+_O__@+PD\@$``$$/A5_[
M__^`O"3S`0``0P^%4?O__X"\)/0!``!(#X5#^___@+PD]0$``$4/A37[__^Z
M`@```$C'QL;___]$B?_H@LW__TB+'"2Z*0```$2)_TB)WN@.R___2(T%W0L`
M`%!3Z9+^___'``````#'1!#\`````.F*_?__Z-C,__\/'X0``````$%7059!
M54%455-(@^PH2(LMHVD``$R-="0<BWT`Z![*__^+?0!(B</H$\K__P^VD[@`
M``!,B?9(C3UF"@``B)"Y````,<#H!>?__TB%P'0)@#@Q#X37`@``,<#H4/'_
M_XM]`.C8R?__N0L```"Z`0```$B--3<+``!(B<?HK\K__TB%P`^$Q@```$B+
M0!"#/<M[```!1(M]`$R+:"@/CK$````QV^M`9@\?A```````2(MV$$B+!9U[
M``!)8]1(BSS0Z!G,__]!B<"+!9![``!%A<`/A>$!``"#PP(YPT2)XP^-TP$`
M`$2)_T2-8P'H3<G__S')2&/33(GN2(G'Z$W+__](A<`/A*0!``!(BS!$BWT`
MBT8,)0`$(``]``0``'2.1(G_2(ET)`CH$<G__TB+="0(N0(````QTDB)Q^B=
MS/__1(M]`$B)QNEE____D$2+?0!$B?_HY,C__[D#````N@$```!(C35("@``
M2(G'Z+O)__](B<-(A<!T-$B+0!"+?0!,BR#HM,C__TB-%20*``!(B<=,B>;H
MPLG__TB+0Q!,BR!!]D0D#D`/A;@!``"+?0#HA\C__[D#````N@$```!(C37R
M"0``2(G'Z%[)__](B<-(A<!T.DR)]DB-/8X(```QP.AEY?__28G$2(7`#X1)
M`0``2(M#$(M]`$R+*.@ZR/__3(GB2(G'3(GNZ$S)__^+?0#H),C__[H!````
M2(TUE@D``$B)Q^@PR/__BWT`28G$Z`7(__],B>9(C16."0``2(G'Z!/)__^+
M?0#HZ\?__TR)]DB-/0H(``#&@+D`````,<#HX^3__TB)!?1Y``!)B<1(A<`/
MA(````"^P`$``$R)Y^A#R___C5`!@_H!=@F#^!$/A>,```!(@\0H6UU!7$%=
M05Y!7\,/'P"+!:IY``!$BWT`C5#_.=H/A8_^__^#^`$/CH;^__^[`0````\?
M1```1(G_@\,!Z%W'__],B>Y(B<?H,LC__SD=;'D``$2+?0!_WNE5_O__D$B+
M/5%Y``#HI/'__TB)!55Y``!)B<1(A<`/A6'___](C3U2"0``,<#HX\G__P\?
M`(!X`0`/A";]___I&OW__Y!(BP41>0``BWT`3(LH2(M#$$R+(.CGQO__3(GN
M3(GGZ/SH___IJ_[__XM]`.C/QO__3(GF2(G'Z$3)___I,/[__XG!2(L%SG@`
M`$R)XDB-/0P)``!(BS`QP.ARR?__9I!52(G]4TB#[`CH(NW__TB)Q^CJ[/__
M2(G#,<#HP.___X7`="5(A>UT((!]``!T&KD$````2(T]DP<``$B)WO.F#Y?`
M'`"$P'0'2(/$"%M=PTB#Q`A(B>];7>FRYO__9I#S#Q[Z05=,C3UK8P``059)
MB=9!54F)]4%408G\54B-+5QC``!33"G]2(/L".C?Q?__2,']`W0?,=L/'X``
M````3(GR3(GN1(GG0?\4WTB#PP%(.=UUZDB#Q`A;74%<05U!7D%?PV9F+@\?
MA```````\P\>^L-F+@\?A```````D/,/'OI(BPU]9P``Z4#&___S#Q[Z2(/L
M"$B#Q`C#````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M
M`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#0U`"UE`"TM```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$;
M`SOL````'````."`__\P`0``H(3__S`&``"@AO__"`$``-"&__\<`0``D(?_
M_U@!````GO__I`$``-">___P`0``0)___Q@"``!@H?__9`(``*"B___4`@``
M$*/__P`#````I/__1`,``$"D__]<`P``D*3__W@#``!0I?__K`,``&"E___`
M`P``4*?__R`$``"`I___-`0``&"H__]D!```,*K__X@$``"`JO__H`0``*"J
M__^X!```8*O___@$``"PMO__L`4``%"Z___\!0``L+K__V`&```@N___J`8`
M`#"[___`!@```````!0``````````7I2``%X$`$;#`<(D`$``!`````<````
MD(7__R\`````1`<0$````#````"LA?__!0`````````D````1````*A____`
M`P````X01@X82@\+=PB``#\:.RHS)"(`````2````&P````PAO__9Q8```!"
M#A"/`D8.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#L@$`T<6#CA!#C!!#BA"
M#B!"#AA"#A!"#@@``$@```"X````5)S__\T`````0@X0CP)"#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`D
M````!`$``-B<__]G`````$$.$(8"00X8@P-'#C`"6PX800X000X(2````"P!
M```@G?__'`(```!"#A"/`D0.&(X#0@X@C01"#BB,!4$.,(8&1`XX@P='#F`"
M^0H..$$.,$$.*$(.($(.&$(.$$(."$<+`&P```!X`0``])[__S\!````2PX0
MC@)"#AB-`T(.((P$00XHA@5$#C"#!D<.P`%,"@XP00XH00X@0@X80@X00@X(
M00L"VPH.,$$.*$$.($(.&$(.$$(."$4+6`X(P\;,S<Y(#L`!@P:&!8P$C0..
M`@`H````Z`$``,2?__]K`````$$.$(8"4@Z@`7\*#A!$#@A*"TD.$$$."```
M`$`````4`@``"*#__^<`````0@X0CP)'#AB.`T(.((T$0@XHC`5$#C"&!E$.
MP"`"A0H.,$$.*$(.($(.&$(.$$(."$@+%````%@"``"TH/__,P````!$#A!9
M#@@`&````'`"``#<H/__0@````!!#A"#`F@."````#````",`@``$*'__[\`
M````0@X0C`)!#AB&`T$.((,$1P[`0`*G"@X@1`X800X00@X(00L0````P`(`
M`)RA__\%`````````%P```#4`@``F*'__^(!````0@X0CP)%#AB.`T(.((T$
M0@XHC`5+#C"&!D$..(,'1P[@(0)E"@XX00XP00XH0@X@0@X80@X00@X(0PL"
MG`[H(4D.\"%@#N@A00[@(0```!`````T`P``**/__R4`````````+````$@#
M``!$H___W`````!*#A"&`@)A"L8."$4+`D`*#@A("T@*Q@X(10M+#@C&(```
M`'@#``#TH___S@$```!!#A"&`DT.4`-C`0H.$$$."$8+%````)P#``"@I?__
M3@````!4#B!Y#@@`%````+0#``#8I?__'0````!$#A!8#@@`/````,P#``#@
MI?__M@````!"#A",`D,.&(8#2PX@@P1$#C!L"@X@00X800X00@X(1`MN#CA)
M#D!T#CA!#C```+0````,!```8*;__T@+````0@X0CP)"#AB.`T(.((T$0@XH
MC`5!#C"&!D$..(,'40[`A`(#`P(.R(0"90[0A`)>#LB$`D(.P(0"`G8*#CA$
M#C!!#BA"#B!"#AA"#A!"#@A*"P-Y`0[(A`)+#M"$`EX.R(0"00[`A`)<#LB$
M`D0.T(0"40[8A`)+#N"$`DL.P(0"`^0$#LB$`D0.T(0":`[(A`)!#L"$`@,_
M`0H.R(0"00[0A`)%"P!(````Q`0``/BP__^>`P```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T0.8`.4`@H..$$.,$$.*$(.($(.&$(.$$(."$0+
M,````!`%``!,M/__7@````!!#A"&`D0.&(,#1`X@`D0*#AA!#A!!#@A!"T0.
M&$0.$$$.""P```!$!0``:'[___L!````0@X0C`)!#AB&`T0.4`-C`0H.&$0.
M$$(."$$+`````$0```!T!0``2+3__V4`````1@X0CP))#AB.`T4.((T$10XH
MC`5$#C"&!D@..(,'1PY`;@XX00XP00XH0@X@0@X80@X00@X(`!0```"\!0``
M<+3__P4``````````````!````#4!0``:+3__Q``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````,`F0```````D"9````````!````````
M``$``````````0````````"^`0````````$`````````R0$````````!````
M`````-,!`````````0`````````B`@````````$`````````7P,````````/
M`````````-`$````````#```````````($````````T`````````@%I`````
M```9`````````&B]0```````&P`````````(`````````!H`````````<+U`
M```````<``````````@`````````]?[_;P`````(`T````````4`````````
M^`Q````````&`````````.`#0```````"@`````````+!0````````L`````
M````&``````````5`````````````````````P``````````P$````````(`
M````````B`4````````4``````````<`````````%P````````!0%$``````
M``<`````````2!-````````(``````````@!````````"0`````````8````
M`````/[__V\`````R!)```````#___]O``````(`````````\/__;P`````$
M$D``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!XO4`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0````````````````````````````/____\`````V&)```````!'
M0T,Z("A43$0M3&EN=7@I(#DN,BXP(#(P,3DP.#,P("AR96QE87-E*0!'0T,Z
M("A43$0M3&EN=7@I(#DN,RXP(#(P,C`P-#`X("AR96QE87-E*0``+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV
M97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN
M:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y
M`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M``````````````````````````````````````````L````!`````@``````
M``"H`D```````*@"````````'`````````````````````$`````````````
M```````3````!P````(`````````Q`)```````#$`@```````"0`````````
M```````````$````````````````````)@````<````"`````````.@"0```
M````Z`(````````@````````````````````!````````````````````#0`
M``#V__]O`@`````````(`T````````@#````````U``````````%````````
M``@````````````````````^````"P````(`````````X`-```````#@`P``
M`````!@)````````!@````$````(`````````!@`````````1@````,````"
M`````````/@,0```````^`P````````+!0```````````````````0``````
M`````````````$X```#___]O`@`````````$$D````````02````````P@``
M```````%``````````(``````````@````````!;````_O__;P(`````````
MR!)```````#($@```````(``````````!@````(````(````````````````
M````:@````0````"`````````$@30```````2!,````````(`0````````4`
M````````"``````````8`````````'0````$````0@````````!0%$``````
M`%`4````````B`4````````%````%@````@`````````&`````````!^````
M`0````8``````````"!`````````(````````!L````````````````````$
M````````````````````>0````$````&`````````"`@0```````("``````
M``#``P``````````````````$``````````0`````````(0````!````!@``
M``````#@(T```````.`C````````H#8``````````````````!``````````
M``````````"*`````0````8`````````@%I```````"`6@````````T`````
M```````````````$````````````````````D`````$````"``````````!@
M0````````&````````!`/P``````````````````$```````````````````
M`)@````!`````@````````!`GT```````$"?````````[```````````````
M``````0```````````````````"F`````0````(`````````,*!````````P
MH````````.@%```````````````````(````````````````````L`````X`
M```#`````````&B]0```````:*T````````(````````````````````"```
M```````(`````````+P````/`````P````````!PO4```````'"M````````
M"`````````````````````@`````````"`````````#(````!@````,`````
M````>+U```````!XK0```````#`"````````!@`````````(`````````!``
M````````T0````$````#`````````*B_0```````J*\```````!8````````
M````````````"``````````(`````````-8````!`````P``````````P$``
M``````"P````````\`$```````````````````@`````````"`````````#?
M`````0````,`````````\,%```````#PL0```````"``````````````````
M```(````````````````````Y0````@````#`````````"#"0```````$+(`
M``````!($```````````````````(````````````````````.H````!````
M,````````````````````!"R````````5`````````````````````$`````
M`````0`````````!`````P````````````````````````!DL@```````/,`
>```````````````````!````````````````````
